==> hledger-web-1.3.1-2-i686.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.3.1
id: hledger-web-1.3.1-6y04Nq0P8pkFHoS1E9gPLH
key: hledger-web-1.3.1-6y04Nq0P8pkFHoS1E9gPLH
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
indefinite: False
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
abi: b19ea70343ddd2dbac6d66e780342680
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hledger-web-1.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hledger-web-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.3.1-6y04Nq0P8pkFHoS1E9gPLH
depends:
    hledger-lib-1.3.1-9j0vkVl0bE1LcY2cgqNVGl
    hledger-1.3.1-DwEgUT2AqSo3xscsiTtJgB base-4.10.0.0
    base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL bytestring-0.10.8.2
    clientsession-0.9.1.2-5lx4F45T8a5Hrim8lKTRYk
    cmdargs-0.10.17-GpLpQKwN3eT2vKDqH6rIIr
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J directory-1.3.0.2
    filepath-1.4.1.2 hjsmin-0.2.0.2-5piZy2NVxbqE2nQQueFQwD
    http-conduit-2.2.3.2-52sQzZr3ihDDo01EMLcTqa
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    conduit-extra-1.1.16-K0CSi1r5Rzl3T85LRH0HhM
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    shakespeare-2.0.14-80JAimk0BGVHInw7Ob1gtk template-haskell-2.12.0.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    wai-extra-3.0.20.0-22olphfrBUWD9PjsExOrxa
    wai-handler-launch-3.0.2.2-8Ik5oBsiylY4ylwgasNMp6
    warp-3.2.13-3xPm02vnKdc1gViEPlMAOd
    yaml-0.8.23.3-4XyoJMIoCeW29jqU9Ss1cp
    yesod-1.4.5-2u2AkZABNYKtIajJKatdx
    yesod-core-1.4.36-CCubKzflnITBeki6j2HPwK
    yesod-form-1.4.15-9KErSEKebUxETahsOep83B
    yesod-static-1.5.3.1-GwvZMCFeZpU89ZjKwOtkk2
    json-0.9.1-H9oi4qjas9E3BwyRmbsDPn
    megaparsec-6.1.1-JyQgsAppHsyCsp6bh0sliz
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 time-1.8.0.2
abi-depends: hledger-lib-1.3.1-9j0vkVl0bE1LcY2cgqNVGl=518737dce3106f208412c29156a1fcbb
             hledger-1.3.1-DwEgUT2AqSo3xscsiTtJgB=a34c5f3009b33e004cb1660af0e95937
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             clientsession-0.9.1.2-5lx4F45T8a5Hrim8lKTRYk=1ac0b4163f9358cd8a479a3362f982c5
             cmdargs-0.10.17-GpLpQKwN3eT2vKDqH6rIIr=814e04fd0adf5c6a510bafac7c16e25e
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             hjsmin-0.2.0.2-5piZy2NVxbqE2nQQueFQwD=e22b4a5505c673508308858bce0578eb
             http-conduit-2.2.3.2-52sQzZr3ihDDo01EMLcTqa=628a0a25e2442340dbad691bfde9407a
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             conduit-extra-1.1.16-K0CSi1r5Rzl3T85LRH0HhM=a6fea8b9e47bc51138a02f6c74aa4aa3
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             shakespeare-2.0.14-80JAimk0BGVHInw7Ob1gtk=d12dae2378f00fd1e1d4bacf864e25ef
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             wai-extra-3.0.20.0-22olphfrBUWD9PjsExOrxa=a42fb84a265f94c5a8c8f19eac76ffcd
             wai-handler-launch-3.0.2.2-8Ik5oBsiylY4ylwgasNMp6=4c3d040ab60dffde4170b8bef9583fd8
             warp-3.2.13-3xPm02vnKdc1gViEPlMAOd=7396680f964ea0423adb7f3256807666
             yaml-0.8.23.3-4XyoJMIoCeW29jqU9Ss1cp=b3ea1feb0465f64d710f4fb6398af8d5
             yesod-1.4.5-2u2AkZABNYKtIajJKatdx=26a5c0215b2aa0f8b354648ccb120d2c
             yesod-core-1.4.36-CCubKzflnITBeki6j2HPwK=4276ebe75d7fa628f8776a933e49a52f
             yesod-form-1.4.15-9KErSEKebUxETahsOep83B=9daf962cda9766c4569ef83bae410fab
             yesod-static-1.5.3.1-GwvZMCFeZpU89ZjKwOtkk2=3917c148966219ab4862442a83632a0c
             json-0.9.1-H9oi4qjas9E3BwyRmbsDPn=b4f9db6197ccc25f88a78dce1a672e26
             megaparsec-6.1.1-JyQgsAppHsyCsp6bh0sliz=2b484d5ea1b9fe6449fe405f8626e332
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-web-1.3.1-14-i686.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.3.1
id: hledger-web-1.3.1-9235EBzwHXt5ojVXIKcVMP
key: hledger-web-1.3.1-9235EBzwHXt5ojVXIKcVMP
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
indefinite: False
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
abi: a2a045de2a5dafa9fc06372ef247759f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hledger-web-1.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hledger-web-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.3.1-9235EBzwHXt5ojVXIKcVMP
depends:
    hledger-lib-1.3.2-2X5kjYjzCrW9S5YCyBqCb4
    hledger-1.3.1-JbhR9aZW5cbGSU2h1DaIRN base-4.10.0.0
    base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL bytestring-0.10.8.2
    clientsession-0.9.1.2-J0Q0ec1VSPNILDBuo7JNfg
    cmdargs-0.10.17-GpLpQKwN3eT2vKDqH6rIIr
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J directory-1.3.0.2
    filepath-1.4.1.2 hjsmin-0.2.0.2-5piZy2NVxbqE2nQQueFQwD
    http-conduit-2.2.3.2-K5gXY4GRHaS6rJlnfLyxiv
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    shakespeare-2.0.14-80JAimk0BGVHInw7Ob1gtk template-haskell-2.12.0.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    wai-extra-3.0.20.0-22olphfrBUWD9PjsExOrxa
    wai-handler-launch-3.0.2.3-30UNn62TyZD1nw6IoRe0p5
    warp-3.2.13-3xPm02vnKdc1gViEPlMAOd
    yaml-0.8.23.3-Hxrrlqfmicr4pp6WmaArsD
    yesod-1.4.5-FLrG5VKO4xODxgbH0umq8f
    yesod-core-1.4.37-5JUXEO7tIU5DzVTIexHRBd
    yesod-form-1.4.16-9blqDcQ4GyNbBja5gCyn3
    yesod-static-1.5.3.1-E7qJV5B4KDPCWDcp6JLmnS
    json-0.9.1-H9oi4qjas9E3BwyRmbsDPn
    megaparsec-6.1.1-JyQgsAppHsyCsp6bh0sliz
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 time-1.8.0.2
abi-depends: hledger-lib-1.3.2-2X5kjYjzCrW9S5YCyBqCb4=3955496e50f8af806d0c5a7712752890
             hledger-1.3.1-JbhR9aZW5cbGSU2h1DaIRN=33a13af10192b4a75a8c038e8fc6dcd0
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             clientsession-0.9.1.2-J0Q0ec1VSPNILDBuo7JNfg=1a1817544f79244eb183405591d7a86d
             cmdargs-0.10.17-GpLpQKwN3eT2vKDqH6rIIr=814e04fd0adf5c6a510bafac7c16e25e
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             hjsmin-0.2.0.2-5piZy2NVxbqE2nQQueFQwD=e22b4a5505c673508308858bce0578eb
             http-conduit-2.2.3.2-K5gXY4GRHaS6rJlnfLyxiv=07e528eb1b8474b5c27868f6df44aacd
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e=8535fcdffdc059c10de789d083424da6
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             shakespeare-2.0.14-80JAimk0BGVHInw7Ob1gtk=d12dae2378f00fd1e1d4bacf864e25ef
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             wai-extra-3.0.20.0-22olphfrBUWD9PjsExOrxa=a42fb84a265f94c5a8c8f19eac76ffcd
             wai-handler-launch-3.0.2.3-30UNn62TyZD1nw6IoRe0p5=d6794118b4bee9a24aac99c068843b54
             warp-3.2.13-3xPm02vnKdc1gViEPlMAOd=7396680f964ea0423adb7f3256807666
             yaml-0.8.23.3-Hxrrlqfmicr4pp6WmaArsD=2eb35475272bb52d4b23b237d5ff79ed
             yesod-1.4.5-FLrG5VKO4xODxgbH0umq8f=21728249c135b876519e4728d859719d
             yesod-core-1.4.37-5JUXEO7tIU5DzVTIexHRBd=bf3053dc868cfde6d96982dc46a87ba4
             yesod-form-1.4.16-9blqDcQ4GyNbBja5gCyn3=c1558747719a797e9afb860d78a9de6f
             yesod-static-1.5.3.1-E7qJV5B4KDPCWDcp6JLmnS=7a3d6f6de4426ee262eb8dff3dbfd9eb
             json-0.9.1-H9oi4qjas9E3BwyRmbsDPn=b4f9db6197ccc25f88a78dce1a672e26
             megaparsec-6.1.1-JyQgsAppHsyCsp6bh0sliz=2b484d5ea1b9fe6449fe405f8626e332
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
